@@ -12,11 +12,11 @@ Regexp::Pattern::License - Regular expressions for legal licenses
 
 =head1 VERSION
 
-Version v3.1.91
+Version v3.1.92
 
 =cut
 
-our $VERSION = version->declare("v3.1.91");
+our $VERSION = version->declare("v3.1.92");
 
 =head1 DESCRIPTION
 
@@ -1708,6 +1708,18 @@ Each of these patterns has the tag B< type:trait >.
 
 =over
 
+=item * any_of
+
+=cut
+
+$RE{any_of} = {
+	caption => 'license grant "any of the following" phrase',
+	tags    => ['type:trait'],
+
+	'pat.alt.subject.trait.scope.line.scope.sentence' =>
+		'(?P<_any_of>(?:any|one or more) of the following(?: licenses(?: at your choice)?)?)[.:]? ?',
+};
+
 =item * clause_retention
 
 =cut
@@ -1783,6 +1795,41 @@ $RE{'fsf_unlimited_retention'} = {
 	'pat.alt.subject.trait.scope.sentence' => $fsf_ullr,
 };
 
+=item * licensed_under
+
+=cut
+
+$RE{licensed_under} = {
+	caption => 'license grant "licensed under" phrase',
+	tags    => ['type:trait'],
+
+	'pat.alt.subject.trait.scope.line.scope.sentence' =>
+		'(?P<_licensed_under>(?:[Ll]icen[sc]ed|[Dd]istribut(?:able|ed)|permitted|provided|[Pp]ublished|[Rr]eleased?) under'
+		. '|(?:in form of source code|may be copied|placed their code|to you) under' # sloppy - may need to include granting keyword
+		. '|(?:[Tt]his|[Mm]y) (?:software|file|work) is under'                       # vague descriptor - object included
+		. '|(?:(?:according|subject) to|[Uu]nder) the (?:conditions|terms) of) ',
+};
+
+=item * or_at_option
+
+=cut
+
+$RE{'or_at_option'} = {
+	caption => 'license grant "or at your option" phrase',
+	tags    => ['type:trait'],
+
+	'pat.alt.subject.trait.scope.line.scope.sentence' =>
+		'(?P<_or_at_option>(?:and|or)(?: ?\(?at your (?:option|choice)\)?)?)',
+};
+
+=item * version
+
+=cut
+
+$RE{'version'} = {
+	tags => ['type:trait'],
+};
+
 =item * version_later
 
 =cut
@@ -1790,11 +1837,6 @@ $RE{'fsf_unlimited_retention'} = {
 $RE{'version_later'} = {
 	caption => 'version "or later"',
 	tags    => ['type:trait'],
-
-	'_pat.alt.subject.trait.scope.line.scope.sentence' => [
-		",? $P{ver_later_postfix}",
-		"$F$E$P{ver_later_para}",
-	],
 };
 
 =item * version_later_paragraph
@@ -1805,7 +1847,8 @@ $RE{'version_later_paragraph'} = {
 	caption => 'version "or later" postfix (paragraphs)',
 	tags    => ['type:trait'],
 
-	'pat.alt.subject.trait.scope.paragraph' => $P{ver_later_para},
+	'pat.alt.subject.trait.scope.paragraph' =>
+		'(?P<_version_later_paragraph>Later versions are permitted)',
 };
 
 =item * version_later_postfix
@@ -1817,9 +1860,17 @@ $RE{'version_later_postfix'} = {
 	tags    => ['type:trait'],
 
 	'pat.alt.subject.trait.scope.line.scope.sentence' =>
-		$P{ver_later_postfix},
+		'\(?(?P<_version_later_postfix>'
+		. $RE{or_at_option}{'pat.alt.subject.trait.scope.line.scope.sentence'}
+		. '(?: any)? (?:later|newer)(?: version)?'
+		. '|or any later at your option)\)?',
 };
 
+$RE{version_later}{'pat.alt.subject.trait.scope.paragraph'}
+	= "(?:$F$E|,? )(?P<version_later>"
+	. $RE{version_later_paragraph}{'pat.alt.subject.trait.scope.paragraph'}
+	. "|$RE{version_later_postfix}{'pat.alt.subject.trait.scope.line.scope.sentence'})";
+
 =item * version_number
 
 =cut
@@ -1828,7 +1879,17 @@ $RE{'version_number'} = {
 	caption => 'version number',
 	tags    => ['type:trait'],
 
-	'pat.alt.subject.trait.scope.line.scope.sentence' => $P{ver_number},
+	'pat.alt.subject.trait.scope.line.scope.sentence' =>
+		'(?P<version_number>\d(?:\.\d+)*)',
+};
+
+=item * version_numberstring
+
+=cut
+
+$RE{'version_numberstring'} = {
+	caption => 'version numberstring',
+	tags    => ['type:trait'],
 };
 
 =item * version_prefix
@@ -1839,9 +1900,21 @@ $RE{'version_prefix'} = {
 	caption => 'version prefix',
 	tags    => ['type:trait'],
 
-	'pat.alt.subject.trait.scope.line.scope.sentence' => $P{ver_prefix},
+	'pat.alt.subject.trait.scope.line.scope.sentence' =>
+		'[Vv](?:ersion |ERSION |\.? ?)',
 };
 
+$RE{version_numberstring}{'pat.alt.subject.trait.scope.line.scope.sentence'}
+	= "(?:$RE{version_prefix}{'pat.alt.subject.trait.scope.line.scope.sentence'})?"
+	. $RE{version_number}{'pat.alt.subject.trait.scope.line.scope.sentence'}
+	. '(?:(?: of the)? License)?';
+
+$RE{version}{'pat.alt.subject.trait.scope.paragraph'}
+	= "(?:$D|[,;] ?|$DD|:?$E)?\\(?(?P<_version>"
+	. $RE{version_numberstring}
+	{'pat.alt.subject.trait.scope.line.scope.sentence'}
+	. "(?:$RE{version_later}{'pat.alt.subject.trait.scope.paragraph'})?)\\)?";
+
 =back
 
 =head2 License combinations
@@ -2060,20 +2133,32 @@ for my $id (@_OBJECTS) {
 	# synthesize metadata: name from caption
 	CAPTION: for ( keys %{ $RE{$id} } ) {
 		my ( $slug, $org ) = (/^caption\.(alt\.org\.($_prop)$_any*)/);
-		$RE{$id}{"name.$slug"}
-			||= $RE{$id}{$_} =~ s/\s/_/gr =~ s/\(/.28/gr =~ s/\)/.29/gr
-			and next CAPTION
-			if ( $slug and $slug =~ /alt\.org\.fedora\.web/ );
-		if ( $org and $org eq 'tldr' ) {
-			$RE{$id}{"name.$slug"} ||= lc( $RE{$id}{$_} ) =~ s/\s/-/gr
+		next CAPTION unless ($org);
+		next CAPTION if ( $RE{$id}{"name.$slug"} );
+		if ( $org eq 'fedora' and $slug =~ /alt\.org\.fedora\.web/ ) {
+			$_ = $RE{$id}{$_};
+			s/\s/_/g;
+			s/\(/.28/g;
+			s/\)/.29/g;
+			$RE{$id}{"name.$slug"} = $_;
+			next CAPTION;
+		}
+		if ( $org eq 'tldr' ) {
+			$_ = lc( $RE{$id}{$_} );
+			s/ /-/g;
+			$RE{$id}{"name.$slug"} = $_
 				if ( $slug eq 'alt.org.tldr' );
-			$RE{$id}{"name.alt.org.$slug"} ||= lc( $RE{$id}{$_} ) =~ s/\s/-/gr
+			$RE{$id}{"name.alt.org.$slug"} = $_
 				if ( $slug eq 'alt.org.tldr.path.short' );
 			next CAPTION;
 		}
-		$RE{$id}{"name.$slug"} ||= $RE{$id}{$_} =~ s/ /_/gr =~ s/"/%22/gr   #"
-			and next CAPTION
-			if ( $org and $org eq 'wikipedia' );
+		if ( $org eq 'wikipedia' ) {
+			$_ = $RE{$id}{$_};
+			s/ /_/g;
+			s/"/%22/g;    #"
+			$RE{$id}{"name.$slug"} = $_;
+			next CAPTION;
+		}
 	}
 
 	# synthesize metadata: series alternate name from name
@@ -2184,7 +2269,7 @@ for my $id (@_OBJECTS) {
 		or $_TYPE{$id} eq 'trait' )
 	{
 # TODO: filter duplicates (by mapping into a hash?)
-		my $caption = _join_pats(
+		$_ = _join_pats(
 			map      {s/^$the?/$the?/r}
 				map  {s/,//gr}
 				map  {s/(?: [Ll]icense)/\(?: \[Ll\]icense\)?/r}
@@ -2195,10 +2280,11 @@ for my $id (@_OBJECTS) {
 				grep {/^(?:caption|name)(?:$_delim|\z)/}
 				keys %{ $RE{$id} }
 		);
+		next unless ($_);
+		s/ - /${DD}/g;
 		$RE{$id}{'_pat.alt.subject.grant.synth.caption'}
-			||= '(?:(?:[Ll]icensed|[Rr]eleased) under|(?:according to|as governed by|under) the (?:conditions|terms) of) '
-			. $caption =~ s/ - /${DD}/gr
-			if ($caption);
+			= '(?:(?:[Ll]icensed|[Rr]eleased) under|(?:according to|as governed by|under) the (?:conditions|terms) of) '
+			. $_;
 	}
 
 	# synthesize subject pattern license from metadata caption
@@ -2234,17 +2320,49 @@ for my $id (@_OBJECTS) {
 	# provide default dynamic pattern: all available patterns
 	$RE{$id}{gen} = sub {
 		my %args = @_;
+
+		my $capture = $args{capture} || 'no';
+
 		my $subjects
 			= $args{subject}
 			? [ split( /,/, $args{subject} ) ]
 			: [ $RE{$id}{'.default_pat'} || @pat_subject ];
 
-		return _pat_compile( $id, $subjects );
+		my $pat = _join_pats( map { $RE{$id}{"pat.alt.subject.$_"} }
+				@{$subjects} );
+
+		return ''
+			unless ($pat);
+
+		$pat =~ s/$_->[0]/$_->[1]/g for (@_re);
+
+		if ( $capture eq 'named' ) {
+			$pat =~ s/\(\?P<\K_//g;
+		}
+		elsif ( $capture eq 'numbered' ) {
+			$pat =~ s/\(\?P<_[^>]+>/(?:/g;
+			$pat =~ s/\(\?P<[^>]+>/(/g;
+		}
+		else {
+			$pat =~ s/\(\?P<[^>]+>/(?:/g;
+		}
+
+		$pat =~ s/$_->[0]/$_->[1]/g for (@_re);
+
+		return qr/$pat/;
 	};
 
-	# offer available patterns through option subjects
+	# option keep: include capturing parantheses in pattern
+	$RE{$id}{'gen_args'}{capture} = {
+		summary => 'include capturing parantheses, named or numbered',
+		schema  => [ 'str*', in => [qw(named numbered no)] ],
+		default => 'no',
+		req     => 1,
+	};
+
+	# option subject: which subject(s) to cover in pattern
 	$RE{$id}{'gen_args'}{subject} = {
-		summary => 'Choose subject',
+		summary => 'Choose subject (or several, comma-separated)',
 		schema  => [ 'str*', in => [@pat_subject] ],
 		default => $RE{$id}{'.default_pat'} || join ',', @pat_subject,
 		req     => 1,
@@ -2264,33 +2382,6 @@ sub _prop_populate
 	}
 }
 
-my %_pat_cache;
-
-sub _pat_compile
-{
-	my ( $id, $subjects ) = @_;
-
-	my $subject = join '_', @{$subjects};
-
-	if ( $_pat_cache{$id}{$subject} ) {
-		return $_pat_cache{$id}{$subject};
-	}
-
-	my $pat
-		= _join_pats( map { $RE{$id}{"pat.alt.subject.$_"} } @{$subjects} );
-	unless ($pat) {
-		return '';
-	}
-
-	for (@_re) {
-		$pat =~ s/$_->[0]/$_->[1]/g;
-	}
-
-	$_pat_cache{$id}{$subject} = qr/$pat/;
-
-	return $_pat_cache{$id}{$subject};
-}
-
 sub _join_pats
 {
 	return '' unless (@_);
